import { mockDB } from "./db";
import { Coupon } from "./models";

export const MockCouponAPI = {
	async getAllCoupons(): Promise<Coupon[]> {
		return mockDB.coupons.toArray();
	},

	async getCouponById(id: number): Promise<Coupon | null> {
		return (await mockDB.coupons.get(id)) ?? null;
	},

	async createCoupon(couponData: Omit<Coupon, "id">): Promise<Coupon> {
		const id = Date.now();

		const newCoupon: Coupon = {
			...couponData,
			id,
		};

		await mockDB.coupons.add(newCoupon);
		return newCoupon;
	},

	async updateCoupon(
		id: number,
		data: Partial<Omit<Coupon, "id">>,
	): Promise<Coupon | null> {
		const existing = await mockDB.coupons.get(id);
		if (!existing) return null;

		const updated: Coupon = {
			...existing,
			...data,
		};

		await mockDB.coupons.put(updated);
		return updated;
	},

	async deleteCoupon(id: number): Promise<boolean> {
		await mockDB.coupons.delete(id);
		return true;
	},
};
