import { MockPurchaseAPI } from "../purchase-mock-api";
import { mockDB } from "../db";

export async function createSamplePurchase() {
	const users = await mockDB.users.where("user_role").equals("customer").toArray();
	if (users.length === 0) throw new Error("No customers found");

	const user = users[Math.floor(Math.random() * users.length)];
	const products = await mockDB.products.toArray();
	if (products.length === 0) throw new Error("No products found");

	const entries = [];

	for (let i = 0; i < Math.floor(Math.random() * 3) + 1; i++) {
		const product = products[Math.floor(Math.random() * products.length)];

		const quantity = Math.floor(Math.random() * 4) + 1;

		entries.push({
			purchase_id: 0,
			product_id: product.id,
			product_variant_id: 0,
			quantity,
		});
	}

	if (entries.length === 0) throw new Error("No suitable product variants found");

	const total = await entries.reduce(async (accP, entry) => {
		const acc = await accP;
		const product = await mockDB.products.get(entry.product_id);
		return acc + ((product?.price ?? 0) * entry.quantity);
	}, Promise.resolve(0));

	// Randomly apply a valid coupon
	const coupons = await mockDB.coupons.toArray();
	const validCoupons = coupons.filter(
		(c) => new Date(c.valid_due) > new Date()
	);
	const useCoupon = validCoupons.length > 0 && Math.random() < 0.5;
	const chosenCoupon = useCoupon
		? validCoupons[Math.floor(Math.random() * validCoupons.length)]
		: null;

	const discountedTotal = chosenCoupon
		? Math.max(0, total - chosenCoupon.discount_amount)
		: total;

	const purchase = await MockPurchaseAPI.createPurchase(
		{
			user_id: user.id,
			used_coupon_id: chosenCoupon?.id ?? null,
			date_purchased: new Date().toISOString(),
			total: discountedTotal,
		},
		entries,
	);

	console.log(
		`Created mock purchase${chosenCoupon ? " with coupon" : ""}:`,
		purchase,
	);
}
