import Dexie, { Table } from "dexie";
import {
	Coupon,
	MockUser,
	MockUserPreferences,
	MockUserStatistics,
	Product,
	ProductCategory,
	ProductCategoryJunction,
	ProductImage,
	ProductVariant,
	Purchase,
	PurchaseEntry,
	Shop,
} from "./models";

class MockDB extends Dexie {
	users!: Table<MockUser, number>;
	preferences!: Table<MockUserPreferences, number>;
	statistics!: Table<MockUserStatistics, number>;
	shops!: Table<Shop, number>;
	products!: Table<Product, number>;
	product_variants!: Table<ProductVariant, number>;
	product_images!: Table<ProductImage, number>;
	product_categories!: Table<ProductCategory, number>;
	product_category_junctions!: Table<ProductCategoryJunction, [number, number]>;
	coupons!: Table<Coupon, number>;
	purchases!: Table<Purchase, number>;
	purchase_entries!: Table<PurchaseEntry, number>;

	constructor() {
		super("MockDB");
		this.version(1).stores({
			users: "++id,username,email,uuid,user_role",
			preferences: "user_id",
			statistics: "user_id",
			shops: "++id,uuid,name",
			products: "++id,shop_id,name",
			product_variants: "++id,product_id",
			product_images: "++id,product_id",
			product_categories: "++id,parent_category_id",
			product_category_junctions: "[product_id+category_id]",
			coupons: "++id,valid_due,name",
			purchases: "++id,user_id,date_purchased",
			purchase_entries: "++id,purchase_id,product_id,product_variant_id",
		});
	}
}

export const mockDB = new MockDB();
