import { UserRegister } from "@/client";

export type UserRole = "owner" | "customer" | "employee" | "manager" | "admin";

export interface MockUser extends Omit<UserRegister, "password"> {
	id: number;
	uuid: string;
	user_role: UserRole;
	shop_id: number | null;
	status: UserRole;
	password: string;
	created_at: string;
	updated_at: string;
	last_login?: string;
	first_name?: string;
	last_name?: string;
	profile_picture?: string;
}

export interface MockUserPreferences {
	user_id: number;
}

export interface MockUserStatistics {
	user_id: number;
	total_spend?: number;
}

export type ShopStatus = "active" | "inactive" | "suspended";

export interface ShopAddress {
	street: string;
	city: string;
	state?: string | null;
	postal_code: string;
	country: string;
}

export interface Shop {
	id: number;
	uuid: string;
	owner_id: number;
	name: string;
	description: string;
	created_at: string;
	updated_at: string;
	status: ShopStatus;
	logo?: string | null;
	contact_email: string;
	contact_phone_number: string;
	address: ShopAddress;
	currency: string;
}

export interface Product {
	id: number;
	shop_id: number;
	name: string;
	description: string;
	price: number;
	stock_quantity: number;
	created_at: string;
	updated_at: string;
}
export interface ProductCategoryJunction {
	product_id: number;
	category_id: number;
}

export interface ProductCategory {
	id: number;
	parent_category_id?: number;
	name: string;
}

export interface ProductImage {
	id: number;
	product_id: number;
	image_id: number;
	image_url: string;
	alt_text: string;
}

export interface ProductCreate {
	name: string;
	description: string;
	price: number;
	stock_quantity: number;
	image_data?: string | undefined;
}

export interface ProductWithDetails extends Product {
	images: ProductImage[];
	categories: ProductCategory[];
}

export interface ProductVariant {
	id: number;
	product_id: number;
	index: number;
	name: string;
	price: number;
	comment?: string;
	created_at: string;
	updated_at: string;
}

export interface Coupon {
	id: number;
	name: string;
	text: string;
	valid_due: string;
	discount_amount: number;
}

export interface Purchase {
	id: number;
	user_id: number;
	used_coupon_id: number | null;
	date_purchased: string;
	total: number;
}

export interface PurchaseEntry {
	id: number;
	purchase_id: number;
	product_id: number;
	product_variant_id: number;
	quantity: number;
}

export interface PurchaseWithDetails extends Purchase {
	user: MockUser;
	coupon?: Coupon | null;
	entries: PurchaseEntryWithProduct[];
}

export interface PurchaseEntryWithProduct extends PurchaseEntry {
	product: Product;
}
