import { mockDB } from "./db";
import { MockUser } from "./models";
import { getCurrentUserDirect } from "./utils/currentUser";

export const MockUserAPI = {
	async getAllUsers(): Promise<MockUser[]> {
		return mockDB.users.toArray();
	},

	async getUserById(userId: number): Promise<MockUser | null> {
		return (await mockDB.users.get(userId)) ?? null;
	},

	async createUser(
		userData: Omit<MockUser, "id" | "created_at" | "updated_at">,
	): Promise<MockUser> {
		const now = new Date().toISOString();
		const id = Date.now();

		const newUser: MockUser = {
			...userData,
			id,
			created_at: now,
			updated_at: now,
		};

		await mockDB.users.add(newUser);
		return newUser;
	},

	async updateUser(
		userId: number,
		data: Partial<Omit<MockUser, "id" | "created_at">>,
	): Promise<MockUser | null> {
		const existingUser = await mockDB.users.get(userId);
		if (!existingUser) return null;

		const updatedUser: MockUser = {
			...existingUser,
			...data,
			updated_at: new Date().toISOString(),
		};

		await mockDB.users.put(updatedUser);
		return updatedUser;
	},

	async deleteUser(userId: number): Promise<boolean> {
		await mockDB.preferences.where("user_id").equals(userId).delete();
		await mockDB.statistics.where("user_id").equals(userId).delete();
		await mockDB.users.delete(userId);
		return true;
	},

	async getCurrentUser(): Promise<MockUser | null> {
		const user = await getCurrentUserDirect();
		if (!user?.id) return null;
		return (await mockDB.users.get(user.id)) ?? null;
	},
};
