import { useMutation, useQuery, useQueryClient } from "@tanstack/react-query";
import { Coupon } from "@/api/mock/models";
import { couponAPI } from "@/api/api";

export function useCoupon(couponId?: number) {
	const queryClient = useQueryClient();

	const coupon = useQuery<Coupon | null>({
		queryKey: ["coupon", couponId],
		queryFn: () => couponAPI.getCouponById(couponId!),
		enabled: !!couponId,
	});

	const createCoupon = useMutation({
		mutationFn: (data: Omit<Coupon, "id">) => couponAPI.createCoupon(data),
		onSuccess: () => {
			queryClient.invalidateQueries({ queryKey: ["coupons"] });
		},
	});

	const updateCoupon = useMutation({
		mutationFn: (data: Partial<Omit<Coupon, "id">>) =>
			couponAPI.updateCoupon(couponId!, data),
		onSuccess: () => {
			queryClient.invalidateQueries({ queryKey: ["coupons"] });
			queryClient.invalidateQueries({ queryKey: ["coupon", couponId] });
		},
	});

	const deleteCoupon = useMutation({
		mutationFn: (id: number) => couponAPI.deleteCoupon(id),
		onSuccess: (_, id) => {
			queryClient.invalidateQueries({ queryKey: ["coupons"] });
			queryClient.removeQueries({ queryKey: ["coupon", id] });
		},
	});

	return { coupon, createCoupon, updateCoupon, deleteCoupon };
}
