import { useMutation, useQuery, useQueryClient } from "@tanstack/react-query";
import { ProductCreate, ProductWithDetails } from "@/api/mock/models";
import { productsAPI } from "@/api/api";

export function useProduct(productId?: number) {
	const queryClient = useQueryClient();

	const product = useQuery<ProductWithDetails | null>({
		queryKey: ["product", productId],
		queryFn: () => productsAPI.getProductById(productId!),
		enabled: !!productId,
	});

	const createProduct = useMutation({
		mutationFn: (data: ProductCreate) => productsAPI.createProduct(data),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: ["products"] }),
	});

	const updateProduct = useMutation({
		mutationFn: (data: Partial<ProductCreate>) =>
			productsAPI.updateProduct(productId!, data),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: ["products"] }),
	});

	const deleteProduct = useMutation({
		mutationFn: () => productsAPI.deleteProduct(productId!),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: ["products"] }),
	});

	return { product, createProduct, updateProduct, deleteProduct };
}
