import { useQuery, useMutation, useQueryClient } from "@tanstack/react-query";
import {
	Purchase,
	PurchaseWithDetails,
} from "@/api/mock/models";
import { purchaseAPI } from "@/api/api";

export function usePurchase(purchaseId?: number) {
	const queryClient = useQueryClient();

	const purchase = useQuery<PurchaseWithDetails | null>({
		queryKey: ["purchase", purchaseId],
		queryFn: () => {
			if (purchaseId === undefined) return Promise.resolve(null);
			return purchaseAPI.getPurchaseWithDetails(purchaseId);
		},
		enabled: purchaseId !== undefined,
	});

	const createPurchase = useMutation({
		mutationFn: (data: Omit<Purchase, "id">) => purchaseAPI.createPurchase(data),
		onSuccess: () => {
			queryClient.invalidateQueries({ queryKey: ["purchases"] });
		},
	});

	const updatePurchase = useMutation({
		mutationFn: (data: Purchase) => purchaseAPI.updatePurchase(data.id, data),
		onSuccess: (_, updatedPurchase) => {
			queryClient.invalidateQueries({ queryKey: ["purchases"] });
			queryClient.invalidateQueries({ queryKey: ["purchase", updatedPurchase.id] });
		},
	});

	const deletePurchase = useMutation({
		mutationFn: (id: number) => purchaseAPI.deletePurchase(id),
		onSuccess: (_, id) => {
			queryClient.invalidateQueries({ queryKey: ["purchases"] });
			queryClient.removeQueries({ queryKey: ["purchase", id] });
		},
	});

	return {
		purchase,
		createPurchase,
		updatePurchase,
		deletePurchase,
	};
}
