import { shopAPI } from "@/api/api";
import { Shop } from "@/api/mock/models";
import { useQuery, useMutation, useQueryClient } from "@tanstack/react-query";

export function useShop() {
	const queryClient = useQueryClient();

	const {
		data: shop,
		isLoading,
		isError,
	} = useQuery<Shop | null>({
		queryKey: ["shop"],
		queryFn: shopAPI.getShop,
	});

	const updateShopMutation = useMutation({
		mutationFn: shopAPI.updateShop,
		onSuccess: () => queryClient.invalidateQueries({ queryKey: ["shop"] }),
	});

	return {
		shop,
		isLoading,
		isError,
		updateShop: updateShopMutation.mutate,
		updateStatus: updateShopMutation.status,
	};
}
