import { useMutation, useQuery, useQueryClient } from "@tanstack/react-query";
import { MockUser } from "@/api/mock/models";
import { usersAPI } from "@/api/api";

export function useUser(userId?: number) {
	const queryClient = useQueryClient();

	const user = useQuery<MockUser | null>({
		queryKey: ["user", userId],
		queryFn: () => usersAPI.getUserById(userId!),
		enabled: !!userId,
	});

	const createUser = useMutation({
		mutationFn: (data: Omit<MockUser, "id" | "created_at" | "updated_at">) =>
			usersAPI.createUser(data),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: ["users"] }),
	});

	const updateUser = useMutation({
		mutationFn: (data: Partial<Omit<MockUser, "id" | "created_at">>) =>
			usersAPI.updateUser(userId!, data),
		onSuccess: () => {
			queryClient.invalidateQueries({ queryKey: ["users"] });
			queryClient.invalidateQueries({ queryKey: ["user", userId] });
		},
	});

	const deleteUser = useMutation({
		mutationFn: () => usersAPI.deleteUser(userId!),
		onSuccess: () => {
			queryClient.invalidateQueries({ queryKey: ["users"] });
			queryClient.removeQueries({ queryKey: ["user", userId] });
		},
	});

	return { user, createUser, updateUser, deleteUser };
}
