import { ProductWithDetails } from "@/api/mock/models";
import Placeholder from "@/assets/placeholder.svg?react";
import {
	Card,
	CardDescription,
	CardHeader,
	CardTitle,
} from "@/components/ui/card";

export function ProductList({
	currency,
	products,
	isLoading,
	onClick,
}: {
	currency: string;
	products: ProductWithDetails[];
	isLoading: boolean;
	onClick: (id: number) => void;
}) {
	if (isLoading) return <p className="col-span-full">Loading...</p>;

	return (
		<ul className="faded-bottom no-scrollbar grid grid-cols-1 gap-4 overflow-auto pb-16 pt-4 sm:grid-cols-2 md:grid-cols-4 xl:grid-cols-6 2xl:grid-cols-8">
			{products.map((product) => (
				<Card
					key={product.id}
					onClick={() => onClick(product.id)}
					className="cursor-pointer overflow-hidden"
				>
					<div className="relative aspect-square w-full overflow-hidden">
						{product.images.length > 0 ? (
							<img
								src={
									product.images.length > 0
										? product.images[0].image_url
										: "/images/placeholder.svg"
								}
								alt={product.name}
								className="h-full w-full object-cover"
							/>
						) : (
							<Placeholder className="h-full w-full fill-gray-100 object-cover text-slate-900 dark:fill-slate-900 dark:text-zinc-500" />
						)}
						<div className="absolute bottom-0 left-0 right-0 flex items-center justify-between bg-gradient-to-t from-background/90 to-background/0 p-2 text-xs">
							<span className="rounded bg-secondary px-2 py-1 text-[10px] font-medium">
								{product.stock_quantity} in stock
							</span>
							<span className="rounded bg-background/70 px-2 py-1 font-semibold">
								{product.price.toFixed(2)} {currency}
							</span>
						</div>
					</div>
					<CardHeader className="p-3 pb-2">
						<CardTitle className="line-clamp-1 text-sm">
							{product.name}
						</CardTitle>
						<CardDescription className="line-clamp-2 text-xs text-muted-foreground">
							{product.description}
						</CardDescription>
					</CardHeader>
				</Card>
			))}
		</ul>
	);
}
