import { ProductWithDetails } from "@/api/mock/models";
import { zodResolver } from "@hookform/resolvers/zod";
import { useEffect } from "react";
import { useForm } from "react-hook-form";
import { z } from "zod";

export const schema = z.object({
	name: z.string().min(1, "Name is required"),
	description: z.string().min(1, "Description is required"),
	price: z.coerce
		.number()
		.min(0.01, "Price must be greater than 0.01")
		.step(0.01),
	stock_quantity: z.coerce.number().int().min(0),
	image_data: z.string().optional(),
});

export type ProductForm = z.infer<typeof schema>;

export function useProductForm(productData?: ProductWithDetails | null) {
	const form = useForm<ProductForm>({
		resolver: zodResolver(schema),
		defaultValues: {
			name: "",
			description: "",
			price: 0,
			stock_quantity: 0,
			image_data: "",
		},
	});

	useEffect(() => {
		if (productData) {
			form.reset({
				name: productData.name,
				description: productData.description,
				price: productData.price,
				stock_quantity: productData.stock_quantity,
				image_data: productData.images[0]?.image_url || "",
			});
		}
	}, [productData, form]);

	return form;
}
