"use client";

import { toast } from "@/hooks/useToast";
import { IconAlertTriangle } from "@tabler/icons-react";
import { ConfirmDialog } from "@/components/confirm-dialog";
import { Coupon } from "../data/schema";
import { useCoupon } from "@/hooks/useCoupon";
import { Alert, AlertDescription, AlertTitle } from "@/components/ui/alert";

interface Props {
	open: boolean;
	onOpenChange: (open: boolean) => void;
	currentRow: Coupon;
}

export function CouponsDeleteDialog({ open, onOpenChange, currentRow }: Props) {
	const { deleteCoupon } = useCoupon(currentRow.id);

	const handleDelete = () => {
		deleteCoupon.mutate(currentRow.id);

		onOpenChange(false);
		toast({
			title: "Coupon deleted",
			description: `"${currentRow.name}" (${currentRow.discount_amount}% off) has been removed.`,
		});
	};

	return (
		<ConfirmDialog
			open={open}
			onOpenChange={onOpenChange}
			handleConfirm={handleDelete}
			title={
				<span className="text-destructive">
					<IconAlertTriangle
						className="mr-1 inline-block stroke-destructive"
						size={18}
					/>{" "}
					Delete Coupon
				</span>
			}
			desc={
				<div className="space-y-4">
					<p>
						Are you sure you want to delete the coupon{" "}
						<span className="font-bold">{currentRow.name}</span>?
						<br />
						This action cannot be undone.
					</p>

					<Alert variant="destructive">
						<AlertTitle>Warning!</AlertTitle>
						<AlertDescription>
							Once removed, this coupon will no longer be available to
							customers.
						</AlertDescription>
					</Alert>
				</div>
			}
			confirmText="Delete"
			destructive
		/>
	);
}
