import React, { useState } from "react";
import useDialogState from "@/hooks/useDialogState";
import { Coupon } from "../data/schema";

type CouponsDialogType = "add" | "edit" | "delete";

interface CouponsContextType {
	open: CouponsDialogType | null;
	setOpen: (type: CouponsDialogType | null) => void;
	currentRow: Coupon | null;
	setCurrentRow: React.Dispatch<React.SetStateAction<Coupon | null>>;
}

const CouponsContext = React.createContext<CouponsContextType | null>(null);

interface Props {
	children: React.ReactNode;
}

export default function CouponsProvider({ children }: Props) {
	const [open, setOpen] = useDialogState<CouponsDialogType>(null);
	const [currentRow, setCurrentRow] = useState<Coupon | null>(null);

	return (
		<CouponsContext.Provider
			value={{ open, setOpen, currentRow, setCurrentRow }}
		>
			{children}
		</CouponsContext.Provider>
	);
}

// eslint-disable-next-line react-refresh/only-export-components
export const useCouponsContext = () => {
	const context = React.useContext(CouponsContext);

	if (!context) {
		throw new Error("useCouponsContext must be used within <CouponsProvider>");
	}

	return context;
};
