import { Header } from "@/components/layout/header";
import { Main } from "@/components/layout/main";
import { ProfileDropdown } from "@/components/profile-dropdown";
import { Search } from "@/components/search";
import { ThemeSwitch } from "@/components/theme-switch";
import { columns } from "./components/coupon-columns";
import { CouponsDialogs } from "./components/coupon-dialog";
import { CouponPrimaryButtons } from "./components/coupon-primary-buttons";
import { CouponsTable } from "./components/coupon-table";
import CouponsProvider from "./context/coupon-context";
import { Coupon, couponListSchema } from "./data/schema";
import { useCoupons } from "@/hooks/useCoupons";

export default function Coupons() {
	const { data, error, isLoading } = useCoupons();

	let couponList: Coupon[] = [];
	if (data) {
		try {
			couponList = couponListSchema.parse(data);
		} catch (e) {
			console.error("Schema validation failed:", e);
			couponList = [];
		}
	}

	return (
		<CouponsProvider>
			<Header fixed>
				<Search />
				<div className="ml-auto flex items-center space-x-4">
					<ThemeSwitch />
					<ProfileDropdown />
				</div>
			</Header>

			<Main>
				<div className="mb-2 flex flex-wrap items-center justify-between space-y-2">
					<div>
						<h2 className="text-2xl font-bold tracking-tight">Coupons</h2>
						<p className="text-muted-foreground">
							Create, edit and manage product discounts.
						</p>
					</div>
					<CouponPrimaryButtons />
				</div>

				{isLoading && (
					<p className="text-muted-foreground">Loading coupons...</p>
				)}
				{error && (
					<p className="text-red-500">
						Failed to load coupons: {(error as Error).message}
					</p>
				)}

				{!isLoading && !error && (
					<div className="-mx-4 flex-1 overflow-auto px-4 py-1 lg:flex-row lg:space-x-12 lg:space-y-0">
						<CouponsTable data={couponList} columns={columns} />
					</div>
				)}
			</Main>

			<CouponsDialogs />
		</CouponsProvider>
	);
}
