"use client";

import { toast } from "@/hooks/useToast";
import { IconAlertTriangle } from "@tabler/icons-react";
import { ConfirmDialog } from "@/components/confirm-dialog";
import { Purchase } from "../data/schema";
import { usePurchase } from "@/hooks/usePurchase";
import { Alert, AlertDescription, AlertTitle } from "@/components/ui/alert";

interface Props {
	open: boolean;
	onOpenChange: (open: boolean) => void;
	currentRow: Purchase;
}

export function PurchasesDeleteDialog({ open, onOpenChange, currentRow }: Props) {
	const { deletePurchase } = usePurchase(currentRow.id);

	const handleDelete = () => {
		deletePurchase.mutate(currentRow.id);

		onOpenChange(false);
		toast({
			title: "Purchase deleted",
			description: `Purchase #${currentRow.id} has been successfully removed.`,
		});
	};

	return (
		<ConfirmDialog
			open={open}
			onOpenChange={onOpenChange}
			handleConfirm={handleDelete}
			title={
				<span className="text-destructive">
					<IconAlertTriangle
						className="mr-1 inline-block stroke-destructive"
						size={18}
					/>{" "}
					Delete Purchase
				</span>
			}
			desc={
				<div className="space-y-4">
					<p>
						Are you sure you want to delete{" "}
						<span className="font-bold">purchase #{currentRow.id}</span>?
						<br />
						This action cannot be undone.
					</p>

					<Alert variant="destructive">
						<AlertTitle>Warning!</AlertTitle>
						<AlertDescription>
							This will permanently remove this purchase and all associated
							entries.
						</AlertDescription>
					</Alert>
				</div>
			}
			confirmText="Delete"
			destructive
		/>
	);
}
