import React, { useState } from "react";
import useDialogState from "@/hooks/useDialogState";
import { Purchase } from "../data/schema";

type PurchasesDialogType = "view" | "delete" | "edit" | "add";

interface PurchasesContextType {
	open: PurchasesDialogType | null;
	setOpen: (type: PurchasesDialogType | null) => void;
	currentRow: Purchase | null;
	setCurrentRow: React.Dispatch<React.SetStateAction<Purchase | null>>;
}

const PurchasesContext = React.createContext<PurchasesContextType | null>(null);

interface Props {
	children: React.ReactNode;
}

export default function PurchasesProvider({ children }: Props) {
	const [open, setOpen] = useDialogState<PurchasesDialogType>(null);
	const [currentRow, setCurrentRow] = useState<Purchase | null>(null);

	return (
		<PurchasesContext.Provider
			value={{ open, setOpen, currentRow, setCurrentRow }}
		>
			{children}
		</PurchasesContext.Provider>
	);
}

// eslint-disable-next-line react-refresh/only-export-components
export const usePurchasesContext = () => {
	const context = React.useContext(PurchasesContext);

	if (!context) {
		throw new Error("usePurchasesContext must be used within <PurchasesProvider>");
	}

	return context;
};
