import { Header } from "@/components/layout/header";
import { Main } from "@/components/layout/main";
import { ProfileDropdown } from "@/components/profile-dropdown";
import { Search } from "@/components/search";
import { ThemeSwitch } from "@/components/theme-switch";
import { getColumns } from "./components/purchase-columns";
import { PurchasesDialogs } from "./components/purchase-dialog";
import { PurchasePrimaryButtons } from "./components/purchase-primary-buttons";
import { PurchasesTable } from "./components/purchase-table";
import PurchasesProvider from "./context/purchase-context";
import { usePurchases } from "@/hooks/usePurchases";
import { Coupon, Purchase } from "@/api/mock/models";
import { purchaseListSchema } from "./data/schema";
import { useCoupons } from "@/hooks/useCoupons";

export default function RecentSalves() {
	const { data, error, isLoading } = usePurchases();
	const { data: couponsData } = useCoupons();
	const couponsMap = new Map<number, Coupon>();
	couponsData?.forEach((c) => couponsMap.set(c.id, c));

	let purchaseList: Purchase[] = [];
	if (data) {
		try {
			purchaseList = purchaseListSchema.parse(data);
		} catch (e) {
			console.error("Schema validation failed:", e);
			purchaseList = [];
		}
	}

	return (
		<PurchasesProvider>
			<Header fixed>
				<Search />
				<div className="ml-auto flex items-center space-x-4">
					<ThemeSwitch />
					<ProfileDropdown />
				</div>
			</Header>

			<Main>
				<div className="mb-2 flex flex-wrap items-center justify-between space-y-2">
					<div>
						<h2 className="text-2xl font-bold tracking-tight">Purchases</h2>
						<p className="text-muted-foreground">
							View, and analyze user purchases.
						</p>
					</div>
					<PurchasePrimaryButtons />
				</div>

				{isLoading && (
					<p className="text-muted-foreground">Loading purchases...</p>
				)}
				{error && (
					<p className="text-red-500">
						Failed to load purchases: {(error as Error).message}
					</p>
				)}

				{!isLoading && !error && (
					<div className="-mx-4 flex-1 overflow-auto px-4 py-1 lg:flex-row lg:space-x-12 lg:space-y-0">
						<PurchasesTable
							data={purchaseList}
							columns={getColumns(couponsMap)}
						/>
					</div>
				)}
			</Main>

			<PurchasesDialogs />
		</PurchasesProvider>
	);
}
