import { z } from "zod";

export const userRoleSchema = z.union([
	z.literal("owner"),
	z.literal("admin"),
	z.literal("manager"),
	z.literal("employee"),
	z.literal("customer"),
]);
export type UserRole = z.infer<typeof userRoleSchema>;

export const userSchema = z.object({
	id: z.number(),
	uuid: z.string().uuid(),
	username: z.string(),
	email: z.string().email(),
	password: z.string(),
	user_role: userRoleSchema,
	shop_id: z.number().nullable(),
	created_at: z.coerce.date(),
	updated_at: z.coerce.date(),
	last_login: z.coerce.date().optional(),
	first_name: z.string().optional(),
	last_name: z.string().optional(),
	phone_number: z.string().optional(),
	profile_picture: z.string().url().optional(),
});

export type User = z.infer<typeof userSchema>;

export const userListSchema = z.array(userSchema);
